wallaroo.wallaroo_ml_ops_api_client.models.status_get_deployment_response_200_sidekicks_item API documentation

# wallaroo.wallaroo_ml_ops_api_client.models.status_get_deployment_response_200_sidekicks_item

View Source

     1from typing import Any, Dict, List, Type, TypeVar, Union
     2
     3import attr
     4
     5from ..models.status_get_deployment_response_200_sidekicks_item_info import \
     6    StatusGetDeploymentResponse200SidekicksItemInfo
     7from ..types import UNSET, Unset
     8
     9T = TypeVar("T", bound="StatusGetDeploymentResponse200SidekicksItem")
    10
    11@attr.s(auto_attribs=True)
    12class StatusGetDeploymentResponse200SidekicksItem:
    13    """ Sidekick engine deployment status.
    14
    15    Attributes:
    16        info (StatusGetDeploymentResponse200SidekicksItemInfo):
    17        statuses (Union[Unset, None, str]):  Statuses of engine sidekick servers.
    18    """
    19
    20    info: StatusGetDeploymentResponse200SidekicksItemInfo
    21    statuses: Union[Unset, None, str] = UNSET
    22    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
    23
    24
    25    def to_dict(self) -> Dict[str, Any]:
    26        info = self.info.to_dict()
    27
    28        statuses = self.statuses
    29
    30        field_dict: Dict[str, Any] = {}
    31        field_dict.update(self.additional_properties)
    32        field_dict.update({
    33            "info": info,
    34        })
    35        if statuses is not UNSET:
    36            field_dict["statuses"] = statuses
    37
    38        return field_dict
    39
    40
    41
    42    @classmethod
    43    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    44        d = src_dict.copy()
    45        info = StatusGetDeploymentResponse200SidekicksItemInfo.from_dict(d.pop("info"))
    46
    47
    48
    49
    50        statuses = d.pop("statuses", UNSET)
    51
    52        status_get_deployment_response_200_sidekicks_item = cls(
    53            info=info,
    54            statuses=statuses,
    55        )
    56
    57        status_get_deployment_response_200_sidekicks_item.additional_properties = d
    58        return status_get_deployment_response_200_sidekicks_item
    59
    60    @property
    61    def additional_keys(self) -> List[str]:
    62        return list(self.additional_properties.keys())
    63
    64    def __getitem__(self, key: str) -> Any:
    65        return self.additional_properties[key]
    66
    67    def __setitem__(self, key: str, value: Any) -> None:
    68        self.additional_properties[key] = value
    69
    70    def __delitem__(self, key: str) -> None:
    71        del self.additional_properties[key]
    72
    73    def __contains__(self, key: str) -> bool:
    74        return key in self.additional_properties

@attr.s(auto_attribs=True)
class StatusGetDeploymentResponse200SidekicksItem: View Source

    12@attr.s(auto_attribs=True)
    13class StatusGetDeploymentResponse200SidekicksItem:
    14    """ Sidekick engine deployment status.
    15
    16    Attributes:
    17        info (StatusGetDeploymentResponse200SidekicksItemInfo):
    18        statuses (Union[Unset, None, str]):  Statuses of engine sidekick servers.
    19    """
    20
    21    info: StatusGetDeploymentResponse200SidekicksItemInfo
    22    statuses: Union[Unset, None, str] = UNSET
    23    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
    24
    25
    26    def to_dict(self) -> Dict[str, Any]:
    27        info = self.info.to_dict()
    28
    29        statuses = self.statuses
    30
    31        field_dict: Dict[str, Any] = {}
    32        field_dict.update(self.additional_properties)
    33        field_dict.update({
    34            "info": info,
    35        })
    36        if statuses is not UNSET:
    37            field_dict["statuses"] = statuses
    38
    39        return field_dict
    40
    41
    42
    43    @classmethod
    44    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    45        d = src_dict.copy()
    46        info = StatusGetDeploymentResponse200SidekicksItemInfo.from_dict(d.pop("info"))
    47
    48
    49
    50
    51        statuses = d.pop("statuses", UNSET)
    52
    53        status_get_deployment_response_200_sidekicks_item = cls(
    54            info=info,
    55            statuses=statuses,
    56        )
    57
    58        status_get_deployment_response_200_sidekicks_item.additional_properties = d
    59        return status_get_deployment_response_200_sidekicks_item
    60
    61    @property
    62    def additional_keys(self) -> List[str]:
    63        return list(self.additional_properties.keys())
    64
    65    def __getitem__(self, key: str) -> Any:
    66        return self.additional_properties[key]
    67
    68    def __setitem__(self, key: str, value: Any) -> None:
    69        self.additional_properties[key] = value
    70
    71    def __delitem__(self, key: str) -> None:
    72        del self.additional_properties[key]
    73
    74    def __contains__(self, key: str) -> bool:
    75        return key in self.additional_properties

Sidekick engine deployment status.

Attributes: info (StatusGetDeploymentResponse200SidekicksItemInfo): statuses (Union[Unset, None, str]): Statuses of engine sidekick servers.

StatusGetDeploymentResponse200SidekicksItem( info: wallaroo.wallaroo_ml_ops_api_client.models.status_get_deployment_response_200_sidekicks_item_info.StatusGetDeploymentResponse200SidekicksItemInfo, statuses: Union[wallaroo.wallaroo_ml_ops_api_client.types.Unset, NoneType, str] = <wallaroo.wallaroo_ml_ops_api_client.types.Unset object>) View Source

    2def __init__(self, info, statuses=attr_dict['statuses'].default):
    3    self.info = info
    4    self.statuses = statuses
    5    self.additional_properties = __attr_factory_additional_properties()

Method generated by attrs for class StatusGetDeploymentResponse200SidekicksItem.

def to_dict(self) -> Dict[str, Any]: View Source

    26    def to_dict(self) -> Dict[str, Any]:
    27        info = self.info.to_dict()
    28
    29        statuses = self.statuses
    30
    31        field_dict: Dict[str, Any] = {}
    32        field_dict.update(self.additional_properties)
    33        field_dict.update({
    34            "info": info,
    35        })
    36        if statuses is not UNSET:
    37            field_dict["statuses"] = statuses
    38
    39        return field_dict

@classmethod
def from_dict(cls: Type[~T], src_dict: Dict[str, Any]) -> ~T: View Source

    43    @classmethod
    44    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    45        d = src_dict.copy()
    46        info = StatusGetDeploymentResponse200SidekicksItemInfo.from_dict(d.pop("info"))
    47
    48
    49
    50
    51        statuses = d.pop("statuses", UNSET)
    52
    53        status_get_deployment_response_200_sidekicks_item = cls(
    54            info=info,
    55            statuses=statuses,
    56        )
    57
    58        status_get_deployment_response_200_sidekicks_item.additional_properties = d
    59        return status_get_deployment_response_200_sidekicks_item

additional_keys: List[str]